@@ -13,7 +13,7 @@ use Test::JsonAPI::Autodoc::Markdown;
 
 our @EXPORT = qw/describe http_ok set_documents_path set_template/;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 my $in_describe;
 my $results;
@@ -247,8 +247,10 @@ The example of F<test.t> is as follows.
         http_ok($req, 200, "returns response");
     };
 
-The following markdown document are outputted after execution of a test
-(document output to F<$project_root/docs/test.md> on default setting).
+The following markdown document are outputted after execution of a test.
+Document will output to F<$project_root/docs/test.md> on default setting.
+($project_root means the directory on which F<cpanfile> discovered while going back to a root directory from a test script is put.
+Therefore, it is necessary to put F<cpanfile> on a project root.)
 
 =begin markdown
 
@@ -371,7 +373,7 @@ Available variables are the followings.
 
 =back
 
-=head3 Example as follows.
+=head3 Example
 
 =begin kolon
 
